"""
Basic views for Application
===========================
"""

import random
from datetime import datetime, timedelta
from flask import Blueprint, render_template, send_from_directory, request, flash, url_for, redirect
from .models import Item, User

# Main blueprint.
bp = Blueprint('views', __name__)

# Blueprint for documentation.
docs_bp = Blueprint('docs', __name__)

@bp.route("/")
def index() -> str:
    """
    Index page.

    """

    # Render template file. Template file is using Jinja2 syntax, and can be passed an arbitrary number
    # of arguments to be used in the template. The template file is located in the templates directory.
    html = render_template("index.html.j2", title="TJTS5901 Example. It was changed by Arno.")
    return html

@bp.route("/test")
def test_item_adding():
    """
    Test item is added
    """

    # for test purpose create random number (unique mail address required)
    ran_int = str(random.randint(0,10000))

    # Create a new user
    user = User()
    user.email = "test" + ran_int + "@gmail.com"
    user.password = "placeholder"
    user.save()

    # Create a new item
    item = Item()
    item.title = "Test title"
    item.description = "This is a test description"
    item.starting_bid = 100
    item.seller = user
    item.save()

    return "OK"

@bp.route("/addItem", methods=('GET', 'POST'))
def add_item():
    """
    AddItem page.

    """
    if request.method == 'POST':
        nItem = request.form.get('nItem')
        description = request.form.get('description')
        starting_price = int(request.form.get('sPrice'))
        error = None
        if not nItem:
            error = 'Item name is required.'
        if not starting_price or starting_price < 1:
            error = 'Starting price must be greater than 0.'

        if error is None:
            # Placeholder for user as long as login function is not defined
            ran_int = str(random.randint(0,10000))
            user = User()
            user.email = "test" + ran_int + "@gmail.com"
            user.password = "placeholder"
            user.save()

            try:
                item = Item(
                    title=nItem,
                    description=description,
                    starting_bid=starting_price,
                    seller=user,
                    closes_at=datetime.utcnow() + timedelta(days=1)

                )
                item.save()
            except Exception as exc:
                error = f"Error creating item: {exc!s}"
            else:
                return redirect(url_for('views.adding_successful'))

            flash(error)

    item = render_template("addItem.html")
    return item

@bp.route("/adding_successful")
def adding_successful():

    return "Item added successfully"

@bp.route("/listBid")
def index():
    """
    listBid page.

    """

    html = render_template("listBid.html")
    return html
